# InlineResponse200Query

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**original** | **str** | The original query term submitted by the user. | [optional] 
**altered** | **str** | The query term after optional spellcheck or corrections. | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

